# எண்ணிக்கை
எண்ணிக்கை என்பது உலகத்தின் ஒவ்வொரு மொழியின் எண்குறி முறைமை படித்தல் மற்றும் எழுதலுக்காக ஒரு பைத்தான் 
நிரலால் ஆகும்.

## நிலை
[![Build Status](https://travis-ci.org/julienmalard/ennikkai.svg?branch=master)](https://travis-ci.org/julienmalard/ennikkai)
[![Build status](https://ci.appveyor.com/api/projects/status/06m0e097gahel2ij/branch/master?svg=true)](https://ci.appveyor.com/project/julienmalard/ennikkai)
[![மேற்பார்க்கப்பட்ட அளவு](https://coveralls.io/repos/github/julienmalard/ennikkai/badge.svg?branch=master)](https://coveralls.io/github/julienmalard/ennikkai?branch=master)

## பயன்பாடு
பைதான் எண் முதல் எதாவது மொழியில் எண் கிடைக்கும்.

```python
from எண்ணிக்கை import உரைக்கு  as உ

உ(123.456, 'தமிழ்')  # தமிழ்
# '௱௨௰௩.௪௫௬'

உ(123.456, 'தமிழ் இடஞ்சார்')  # இடஞ்சார் தமிழ் எண்ணுரு முறைமை
# '௧௨௩.௪௫௬'

உ(123.456, 'ߒߞߏ')  # ந்கோ மொழி
# '߁߂߃.߄߅߆'

```

எதாவது மொழி முதல் வேறு மொழிக்கும் மொழிபெயர்ப்பு செய்யலாம்.

```python
from எண்ணிக்கை import உரைக்கு as உ

உ('૧૨૩૪.૫૬', 'தமிழ்')  # குஜராதீ மூலம் தமிழ்
# '௲௨௱௩௰௪.௫௬'
```

எதாவது மொழி முதல் பைத்தான் எண் வரை மாற்றலாம்.

```python
from எண்ணிக்கை import எண்ணுக்கு as எ, உரைக்கு as உ

எ('一百二十三。四五六')  # சினீ மொழி
# 123.456

அ = எ('߁߂߃') * எ('௰')
ஆ = எ('૪')
இ = அ + ஆ
உ(இ, 'فارسی')
# '۱۲۳۴'
```

எதாவது மொழிக்கு வழக்கமான வெளிப்பாடு பெற்றலாம்.

```python
import re
from எண்ணிக்கை import சுருங்குறித்தொடர் as சு

வ = சு('தமிழ்')
re.search(வ, 'எண் = ௱௨௰௩.௪௫௬').group()
# '௱௨௰௩.௪௫௬'
```

## நிறுவல்
    pip install ennikkai

## சேர்க்கப்பட்ட மொழிகள்

`எண்ணிக்கை` என்பது நிரலால் **எல்லா மொழிகளின்** எண்களை மொழிபெயர்ப்பு செய்ய முடியும். 

எதாவது ஒரு மொழியை மறந்து விட்டோம என்றால், எங்களுக்கு [சொல்லவும்](https://github.com/julienmalard/ennikkai/issues). நாங்கள் அதை சேர்ப்போம்.

#### ஆதரிக்கப்பட்ட எண்ணுரு முறைமைகள்
* தமிழ்
* தமிழ் இடஞ்சார்
* عربية
* فارسی
* ߒߞߏ
* देवनागरी
* বাংলা
* ਪੰਜਾਬੀ
* ગુજરાતી
* ଓଡ଼ିଆ
* తెలుగు
* ಕನ್ನಡ
* മലയാളം
* മലയാളം സ്ഥാനിക
* සිංහල
* සිංහල ස්ථානීය
* ไทย
* ລາວ
* བོད་ཡིག
* တိုင်းလိုင်
* မြန်မာ
* လိၵ်ႈတႆး
* ግዕዝ
* ខ្មែរ
* ᠮᠣᠩᠭᠣᠯ ᠬᠡᠯᠡ
* ᤕᤠᤰᤌᤢᤱ ᤐᤠᤴ
* ᨣᩴᩣᩱᨴᩭ
* ᨲ᩠ᩅᩫᨾᩮᩥᩬᨦ
* ᬩᬮᬶ
* ᮞᮥᮔ᮪ᮓ
* ᰴᰩᰛᰴᰧᰛ
* ᱚᱞ ᱪᱤᱠᱤ
* 汉语
* 进位汉语
* 花碼
* ꕙꔤ
* ꢱꣃꢬꢵꢰ꣄ꢜ꣄ꢬ
* ꤊꤢ꤬ꤛꤢ꤭ ꤜꤟꤤ꤬
* ꦗꦮ
* ꨌꨩꨠ
* ꯃꯤꯇꯩ
* 𐒋𐒘𐒈𐒑𐒛𐒒𐒕𐒀
* 𐴇𐴝𐴕𐴞𐴉𐴞
* 𑀩𑁆𑀭𑀸𑀳𑀫𑀻
* 𑃐𑃦𑃝𑃗 𑃐𑃦𑃖𑃛𑃣𑃗
* 𑄃𑄧𑄏
* 𑆯𑆳𑆫𑆢𑆳
* 𑋝𑋡𑋟𑋐𑋢
* 𑐥𑑂𑐬𑐔𑐮𑐶𑐟 𑐣𑐾𑐥𑐵𑐮
* 𑒞𑒱𑒩𑒯𑒳𑒞𑒰
* 𑘦𑘻𑘚𑘲
* 𑚔𑚭𑚊𑚤𑚯
* 𑜒𑜑𑜪𑜨
* 𑢹𑣗𑣁𑣜𑣊 𑣏𑣂𑣕𑣂
* 𑰥𑰹𑰎𑰿𑰬𑰲𑰎𑰱
* 𑴎𑴽𑵀𑴘𑴲
* 𑵶𑶓𑶕𑶂𑶋
* 𖩃𖩓𖩑
* 𖬖𖬰𖬝𖬵 𖬄𖬶𖬟 𖬌𖬣𖬵
* 𞄀𞄩𞄰𞄁𞄦𞄱𞄂𞄤𞄳𞄬𞄃𞄥𞄳
* 𞤀𞤣𞤤𞤥
* ꛀꛣꚧꚳ
* latin
* Mayab'

